@@ -78,4 +78,4 @@ class ZiptzBuildHook(BuildHookInterface):
 
                 if 'exclude' not in build_data:
                     build_data['exclude'] = []
-                build_data['exclude'] = [included.path]
+                build_data['exclude'] = [included.relative_path]
